### R code from vignette source 'soilwaterfun_vignette.Rnw'

###################################################
### code chunk number 1: soilwaterfun_vignette.Rnw:83-89
###################################################
# Set a few Sweave options:
options( 
    width       = 65,  # width of R output
    prompt      = " ", # Sign preceding R input in R-GUI
    continue    = " "  # same, but after 2nd line
)   # 


###################################################
### code chunk number 2: soilwaterfun_vignette.Rnw:166-169 (eval = FALSE)
###################################################
## install.packages(
##     pkgs  = "soilwaterfun", 
##     repos = "http://R-Forge.R-project.org" )


###################################################
### code chunk number 3: soilwaterfun_vignette.Rnw:180-183 (eval = FALSE)
###################################################
## install.packages(
##     pkgs  = "soilwaterfun_1.0.0.zip", 
##     repos = NULL )


###################################################
### code chunk number 4: soilwaterfun_vignette.Rnw:190-191
###################################################
library( "soilwaterfun" ) 


###################################################
### code chunk number 5: soilwaterfun_vignette.Rnw:230-239
###################################################
pTheta <- fun.vangenuchten.theta.h( 
    h       = c(0,0.01,0.1,1,10,100,158),  # [meter]
    alpha   = 3.561099,                    # [meter-1] 
    n       = 1.212074,                    # [-] 
    thetaS  = 0.4162380,                   # [-] 
    thetaR  = 0                            # [-] 
)   #
#
pTheta 


###################################################
### code chunk number 6: soilwaterfun_vignette.Rnw:247-256
###################################################
ph <- fun.vangenuchten.h.theta( 
    theta   = pTheta, 
    alpha   = 3.561099,                    # [meter-1] 
    n       = 1.212074,                    # [-] 
    thetaS  = 0.4162380,                   # [-] 
    thetaR  = 0                            # [-] 
)   #
#
ph


###################################################
### code chunk number 7: soilwaterfun_vignette.Rnw:263-278
###################################################
curve( 
    fun.vangenuchten.theta.h( 
        h       = x, 
        alpha   = 3.561099, 
        n       = 1.212074, 
        thetaS  = 0.4162380, 
        thetaR  = 0  
    ),  #
    xlim = c(0.001,158), 
    col  = "red", 
    log  = "x", 
    xlab = "h, pressure head [m]", 
    ylab = expression( theta~", water content [-]" ), 
    main = expression( 'van Genuchten 1980: '~theta=='f(h)' ) 
)   #


###################################################
### code chunk number 8: soilwaterfun_vignette.Rnw:285-300
###################################################
curve( 
    fun.vangenuchten.h.theta( 
        theta   = x, 
        alpha   = 3.561099, 
        n       = 1.212074, 
        thetaS  = 0.4162380, 
        thetaR  = 0  
    ),  #
    xlim = c(0,0.5), 
    col  = "red", 
    log  = "y", 
    ylab = "h, pressure head [m]", 
    xlab = expression( theta~", water content [-]" ), 
    main = expression( 'van Genuchten 1980: '~h=='f('*theta*')' ) 
)   #


###################################################
### code chunk number 9: soilwaterfun_vignette.Rnw:336-345
###################################################
pTheta <- fun.brooks.corey.theta.h( 
    h       = c(0,0.01,0.1,1,10,100,158),   # [meter] 
    hA      = 0.01,                         # [meter] 
    thetaS  = 0.4162380,                    # [-]
    thetaR  = 0,                            # [-]
    lambda  = 0.3                           # [-] 
)   #
#
pTheta 


###################################################
### code chunk number 10: soilwaterfun_vignette.Rnw:352-368
###################################################
curve( 
    fun.brooks.corey.theta.h( 
        h       = x, 
        hA      = 0.01,                     # [meter] 
        thetaS  = 0.4162380,                # [-]
        thetaR  = 0,                        # [-]
        lambda  = 0.3                       # [-] 
    ), 
    xlim = c(0.001,158), 
    col  = "red", 
    log  = "x", 
    xlab = "h, pressure head [m]", 
    ylab = expression( theta~", water content [-]" ), 
    main = expression( 'Brooks and Corey 1964: '~theta=='f(h)' ) 
)   #
abline( v = 0.01 )


###################################################
### code chunk number 11: soilwaterfun_vignette.Rnw:382-390
###################################################
pTheta <- fun.campbell.theta.h( 
    h       = c(0,0.01,0.1,1,10,100,158),  # [meter] 
    hA      = 0.01,                        # [meter] 
    thetaS  = 0.4162380,                   # [-] 
    bPar    = 3.3                          # [-] 
)   #
#
pTheta 


###################################################
### code chunk number 12: soilwaterfun_vignette.Rnw:397-412
###################################################
curve( 
    fun.campbell.theta.h( 
        h       = x,                       # [meter] 
        hA      = 0.01,                    # [meter] 
        thetaS  = 0.4162380,               # [-] 
        bPar    = 3.3                      # [-] 
    ), 
    xlim = c(0.001,158), 
    col  = "red", 
    log  = "x", 
    xlab = "h, pressure head [m]", 
    ylab = expression( theta~", water content [-]" ), 
    main = expression( 'Campbell 1974: '~theta=='f(h)' ) 
)   #
abline( v = 0.01 )


